#ifndef _ADATA_METHODS_H
#define _ADATA_METHODS_H

#include "device.h"

/*
** The error method; should never be called if things are working correctly.
*/
extern MethodResult
methodError(
  DeviceContext* pDevCtx, ...);

/*
** MethodFlash methods
*/

extern MethodResult
methodFlashXrc2l(
  DeviceContext* pDevCtx,
  os_boolean     write,
  os_uint32      location,
  os_uint8*      value);

extern MethodResult
methodFlashPlxbased(
  DeviceContext* pDevCtx,
  os_boolean     write,
  os_uint32      location,
  os_uint8*      value);

extern MethodResult
methodFlashXpl(
  DeviceContext* pDevCtx,
  os_boolean     write,
  os_uint32      location,
  os_uint8*      value);

extern MethodResult
methodFlashXrc2n(
  DeviceContext* pDevCtx,
  os_boolean     write,
  os_uint32      location,
  os_uint8*      value);

extern MethodResult
methodFlashXp(
  DeviceContext* pDevCtx,
  os_boolean     write,
  os_uint32      location,
  os_uint8*      value);

/*
** MethodConfigMem
*/

extern MethodResult
methodConfigMemPlxbased(
  DeviceContext* pDevCtx,
  os_boolean     write,
  unsigned long  location,
  os_uint32*     value);

extern MethodResult
methodConfigMemXpl(
  DeviceContext* pDevCtx,
  os_boolean     write,
  unsigned long  location,
  os_uint32*     value);

/*
** MethodIntEnab
*/

extern MethodResult
methodIntEnabPlxbased(
  DeviceContext* pDevCtx,
  os_boolean     enable);

extern MethodResult
methodIntEnabXplRev0(
  DeviceContext* pDevCtx,
  os_boolean     enable);

extern MethodResult
methodIntEnabXplRev1(
  DeviceContext* pDevCtx,
  os_boolean     enable);

/*
** MethodIsr
*/

extern MethodResult
methodIsrPlxbased(
  DeviceContext* pDevCtx);

extern MethodResult
methodIsrXpl(
  DeviceContext* pDevCtx);

/*
** MethodFpga
*/

extern MethodResult
methodFpgaPlxbased(
  DeviceContext* pDevCtx,
  MethodFpgaOp   op,
  void*          operand);

extern MethodResult
methodFpgaXpl(
  DeviceContext* pDevCtx,
  MethodFpgaOp   op,
  void*          operand);

/*
** MethodSelectMap
*/

extern MethodResult
methodSelectMapPlxbased(
  DeviceContext* pDevCtx,
  os_boolean     write,
  os_uint8*      operand);

extern MethodResult
methodSelectMapXpl(
  DeviceContext* pDevCtx,
  os_boolean     write,
  os_uint8*      operand);

/*
** MethodConfigSpace
*/

extern MethodResult
methodConfigSpacePlxbased(
  DeviceContext* pDevCtx,
  os_boolean     write,
  unsigned int   space,
  os_uint32*     value);

extern MethodResult
methodConfigSpaceXpl(
  DeviceContext* pDevCtx,
  os_boolean     write,
  unsigned int   space,
  os_uint32*     value);

/*
** MethodAddDmaBuffer
*/

extern MethodResult
methodAddDmaBufferPlxbased(
  DeviceContext*  pDevCtx,
  unsigned int    channel,
  unsigned int    index,
  DmaScatterNode* snode);

extern MethodResult
methodAddDmaBufferXplrev0(
  DeviceContext*  pDevCtx,
  unsigned int    channel,
  unsigned int    index,
  DmaScatterNode* snode);

extern MethodResult
methodAddDmaBufferXplrev1(
  DeviceContext*  pDevCtx,
  unsigned int    channel,
  unsigned int    index,
  DmaScatterNode* snode);

/*
** MethodDoDma
*/

extern MethodResult
methodDoDmaPlxbased(
  DeviceContext*  pDevCtx,
  unsigned int    channel,
  os_boolean      start,
  os_uint32       mode,
  unsigned int    numBuffer);

extern MethodResult
methodDoDmaXplrev0(
  DeviceContext*  pDevCtx,
  unsigned int    channel,
  os_boolean      start,
  os_uint32       mode,
  unsigned int    numBuffer);

extern MethodResult
methodDoDmaXplrev1(
  DeviceContext*  pDevCtx,
  unsigned int    channel,
  os_boolean      start,
  os_uint32       mode,
  unsigned int    numBuffer);

/*
** MethodClockWord
*/

extern MethodResult
methodClockWordIcd2061(
  DeviceContext* pDevCtx,
  unsigned int   clockIndex,
  os_uint32      fref,
  os_uint32      freq,
  os_uint32*     actual,
  os_uint32*     clockWord);

extern MethodResult
methodClockWordIcs307(
  DeviceContext* pDevCtx,
  unsigned int   clockIndex,
  os_uint32      fref,
  os_uint32      freq,
  os_uint32*     actual,
  os_uint32*     clockWord);

/*
** MethodClockProg
*/

extern MethodResult
methodClockProgPlxbased(
  DeviceContext* pDevCtx,
  os_uint32      freq,
  os_uint32      clockWord,
  os_boolean     bBefore);

extern MethodResult
methodClockProgXplrev0(
  DeviceContext* pDevCtx,
  os_uint32      freq,
  os_uint32      clockWord,
  os_boolean     bBefore);

extern MethodResult
methodClockProgXplrev2(
  DeviceContext* pDevCtx,
  os_uint32      freq,
  os_uint32      clockWord,
  os_boolean     bBefore);

#endif
